<?php

namespace Location\PushNotification\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Location\PushNotification\Http\Requests\PushNotificationRequest;
use Location\PushNotification\Interfaces\PushNotificationRepositoryInterface;
use Location\PushNotification\Models\PushNotification;

/**
 * Resource controller class for push_notification.
 */
class PushNotificationResourceController extends BaseController
{

    /**
     * Initialize push_notification resource controller.
     *
     * @param type PushNotificationRepositoryInterface $push_notification
     *
     * @return null
     */
    public function __construct(PushNotificationRepositoryInterface $push_notification)
    {
        parent::__construct();
        $this->repository = $push_notification;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Location\PushNotification\Repositories\Criteria\PushNotificationResourceCriteria::class);
    }

    /**
     * Display a list of push_notification.
     *
     * @return Response
     */
    public function index(PushNotificationRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Location\PushNotification\Repositories\Presenter\PushNotificationPresenter::class)
                ->$function();
        }

        $push_notifications = $this->repository->paginate();

        return $this->response->setMetaTitle(trans('push_notification::push_notification.names'))
            ->view('push_notification::push_notification.index', true)
            ->data(compact('push_notifications', 'view'))
            ->output();
    }

    /**
     * Display push_notification.
     *
     * @param Request $request
     * @param Model   $push_notification
     *
     * @return Response
     */
    public function show(PushNotificationRequest $request, PushNotification $push_notification)
    {

        if ($push_notification->exists) {
            $view = 'push_notification::push_notification.show';
        } else {
            $view = 'push_notification::push_notification.new';
        }

        return $this->response->setMetaTitle(trans('app.view') . ' ' . trans('push_notification::push_notification.name'))
            ->data(compact('push_notification'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new push_notification.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(PushNotificationRequest $request)
    {

        $push_notification = $this->repository->newInstance([]);
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('push_notification::push_notification.name')) 
            ->view('push_notification::push_notification.create', true) 
            ->data(compact('push_notification'))
            ->output();
    }

    /**
     * Create new push_notification.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(PushNotificationRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $push_notification                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('push_notification::push_notification.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('push_notification/push_notification/' . $push_notification->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/push_notification/push_notification'))
                ->redirect();
        }

    }

    /**
     * Show push_notification for editing.
     *
     * @param Request $request
     * @param Model   $push_notification
     *
     * @return Response
     */
    public function edit(PushNotificationRequest $request, PushNotification $push_notification)
    {
        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('push_notification::push_notification.name'))
            ->view('push_notification::push_notification.edit', true)
            ->data(compact('push_notification'))
            ->output();
    }

    /**
     * Update the push_notification.
     *
     * @param Request $request
     * @param Model   $push_notification
     *
     * @return Response
     */
    public function update(PushNotificationRequest $request, PushNotification $push_notification)
    {
        try {
            $attributes = $request->all();

            $push_notification->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('push_notification::push_notification.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('push_notification/push_notification/' . $push_notification->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('push_notification/push_notification/' . $push_notification->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the push_notification.
     *
     * @param Model   $push_notification
     *
     * @return Response
     */
    public function destroy(PushNotificationRequest $request, PushNotification $push_notification)
    {
        try {

            $push_notification->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('push_notification::push_notification.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('push_notification/push_notification/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('push_notification/push_notification/' . $push_notification->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple push_notification.
     *
     * @param Model   $push_notification
     *
     * @return Response
     */
    public function delete(PushNotificationRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('push_notification::push_notification.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('push_notification/push_notification'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/push_notification/push_notification'))
                ->redirect();
        }

    }

    /**
     * Restore deleted push_notifications.
     *
     * @param Model   $push_notification
     *
     * @return Response
     */
    public function restore(PushNotificationRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('push_notification::push_notification.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/push_notification/push_notification'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/push_notification/push_notification/'))
                ->redirect();
        }

    }

}
